==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/test/java/org/apache/webbeans/test/injection/circular/beans/CircularNormalInConstructor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.injection.circular.beans;

import javax.enterprise.context.RequestScoped;
import javax.inject.Inject;
import javax.inject.Named;

@RequestScoped
@Named("org.apache.webbeans.test.injection.circular.beans.CircularNormalInConstructor")
public class CircularNormalInConstructor
{
    CircularConstructorOrProducerMethodParameterBean B;
    
    private boolean SAY_HELLO = false;
    
    public CircularNormalInConstructor()
    {
        
    }
    
    @Inject
    public CircularNormalInConstructor(CircularConstructorOrProducerMethodParameterBean B)
    {
        this.B = B;
    }
    
    public void sayHello()
    {
        SAY_HELLO = true;
        
        B.sayHello();
    }
    
    public boolean getSAYHELLO()
    {
        return this.SAY_HELLO;
    }
    
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/injection/circular/beans/CircularNormalInConstructor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.injection.circular.beans;

import jakarta.enterprise.context.RequestScoped;
import jakarta.inject.Inject;
import jakarta.inject.Named;

@RequestScoped
@Named("org.apache.webbeans.test.injection.circular.beans.CircularNormalInConstructor")
public class CircularNormalInConstructor
{
    CircularConstructorOrProducerMethodParameterBean B;
    
    private boolean SAY_HELLO = false;
    
    public CircularNormalInConstructor()
    {
        
    }
    
    @Inject
    public CircularNormalInConstructor(CircularConstructorOrProducerMethodParameterBean B)
    {
        this.B = B;
    }
    
    public void sayHello()
    {
        SAY_HELLO = true;
        
        B.sayHello();
    }
    
    public boolean getSAYHELLO()
    {
        return this.SAY_HELLO;
    }
    
}
